@@ -43,13 +43,17 @@ class AthenaClient:
         self._user_name = user_name
         self._password = password
 
-    def databases(self):
+    def databases(self, result_as_df=True):
         """Returns all the schemas available in Athena"""
         try:
             payload = json.dumps({"user_name": self._user_name, "password": self._password})
             r = requests.post(SERVICE_URL + API_GET_ATHENA_DATABASES, data=payload, headers=HEADERS)
             response = r.json()
-            return response
+            if result_as_df:
+                response_as_df = pd.DataFrame.from_dict(response, orient="index")
+                return response_as_df
+            else:
+                return response
         except requests.exceptions.HTTPError as err_h:
             print(err_h)
         except requests.exceptions.ConnectionError as err_c:
@@ -59,13 +63,17 @@ class AthenaClient:
         except requests.exceptions.RequestException as err:
             print(err)
 
-    def tables(self, schema_name):
+    def tables(self, schema_name, result_as_df=True):
         """Returns all the tables present in a schema"""
         try:
             payload = json.dumps({"user_name": self._user_name, "password": self._password, "schema_name": schema_name})
             r = requests.post(SERVICE_URL + API_GET_ATHENA_TABLES, data=payload, headers=HEADERS)
             response = r.json()
-            return response
+            if result_as_df:
+                response_as_df = pd.DataFrame.from_dict(response, orient="index")
+                return response_as_df
+            else:
+                return response
         except requests.exceptions.HTTPError as err_h:
             print(err_h)
         except requests.exceptions.ConnectionError as err_c:
@@ -75,14 +83,18 @@ class AthenaClient:
         except requests.exceptions.RequestException as err:
             print(err)
 
-    def top(self, schema_name, table_name, limit=None):
+    def top(self, schema_name, table_name, limit=None, result_as_df=True):
         """Returns records from a table"""
         try:
             payload = json.dumps({"user_name": self._user_name, "password": self._password, "schema_name": schema_name,
                                   "table_name": table_name, "limit": limit})
             r = requests.post(SERVICE_URL + API_QUERY_ATHENA_TABLE, data=payload, headers=HEADERS)
             response = r.json()
-            return response
+            if result_as_df:
+                response_as_df = pd.DataFrame.from_dict(response, orient="index")
+                return response_as_df
+            else:
+                return response
         except requests.exceptions.HTTPError as err_h:
             print(err_h)
         except requests.exceptions.ConnectionError as err_c:
